@@ -3,10 +3,9 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
+from pulpcore.client.pulp_file.api.acs_file_api import AcsFileApi
 from pulpcore.client.pulp_file.api.content_files_api import ContentFilesApi
 from pulpcore.client.pulp_file.api.distributions_file_api import DistributionsFileApi
-from pulpcore.client.pulp_file.api.exporters_file_exports_api import ExportersFileExportsApi
-from pulpcore.client.pulp_file.api.exporters_filesystem_api import ExportersFilesystemApi
 from pulpcore.client.pulp_file.api.publications_file_api import PublicationsFileApi
 from pulpcore.client.pulp_file.api.remotes_file_api import RemotesFileApi
 from pulpcore.client.pulp_file.api.repositories_file_api import RepositoriesFileApi
